@@ -6,7 +6,7 @@
     This script is a stand-alone application, and can be run from anywhere with a connection to the internet.
     It runs on either unix or windows.  It requires only the MadrigalWeb python module to be installed.
 
-$Id: globalDownload.py 6116 2017-06-21 14:33:21Z brideout $
+$Id: globalDownload.py 6435 2018-02-20 16:50:05Z brideout $
 """
 
 usage = """
@@ -312,7 +312,7 @@ def excludeExperimentsUsingExpName(expList, expName):
 
 
 
-def getExperimentFileList(server, expList, includeNonDefault):
+def getExperimentFileList(server, expList, includeNonDefault, verbose=False):
     """getExperimentFileList returns a list of MadrigalExperimentFile objects given an experiment list.
 
     Inputs::
@@ -330,6 +330,7 @@ def getExperimentFileList(server, expList, includeNonDefault):
     retList = []
 
     for exp in expList:
+        time.sleep(0.5)
         try:
             theseExpFiles = server.getExperimentFiles(exp.id, includeNonDefault)
         except:
@@ -337,6 +338,9 @@ def getExperimentFileList(server, expList, includeNonDefault):
             continue
         for expFile in theseExpFiles:
             retList.append(expFile)
+            
+        if verbose:
+            print('Analyzed exp url %s' % (exp.url))
 
     return retList
 
@@ -721,7 +725,7 @@ if excludeExpName != None:
     expList = excludeExperimentsUsingExpName(expList, excludeExpName)
 
 # get list of all experiment files given the expList
-expFileList = getExperimentFileList(server, expList, includeNonDefault)
+expFileList = getExperimentFileList(server, expList, includeNonDefault, verbose)
 
 
 # filter expFileList using kindat filter if needed
@@ -773,6 +777,7 @@ for i in range(numFiles):
             else:
                 count += 1
 
+    time.sleep(0.5)
     try:
         server.downloadFile(expFileList[i].name, saveName,
                             user_fullname, user_email, user_affiliation,
