@@ -5,7 +5,7 @@
     This script is a stand-alone application, and can be run from anywhere with a connection to the internet.
     It runs on either unix or windows.  It requires only the MadrigalWeb python module to be installed.
 
-$Id: globalIsprint.py 6116 2017-06-21 14:33:21Z brideout $
+$Id: globalIsprint.py 6932 2019-07-10 15:27:19Z brideout $
 """
 
 usage = """
@@ -24,8 +24,8 @@ usage = """
         --parms=<Madrigal parms> - a comma delimited string listing the desired Madrigal parameters
                                     in mnemonic form.  (Example: gdalt,dte,te).  Data will be returned
                                     in the same order as given in this string. See
-                                    http://madrigal.haystack.mit.edu/cgi-bin/madrigal/getMetadata and
-                                    choose "Parameter code table" for all possible parameters
+                                    http://cedar.openmadrigal.org/parameterMetadata/
+                                    for all possible parameters
 
         --output=<output file or directory name> - the file or directory name to store the resulting data.
                                                    If you give a file, all output will be stored in a single
@@ -348,6 +348,7 @@ def getExperimentFileList(server, expList, verbose):
     retList = []
 
     for i, exp in enumerate(expList):
+        time.sleep(0.5)
         if verbose:
             print(('checking experiment %i of %i' % (i,len(expList))))
         try:
@@ -746,11 +747,12 @@ if not format is None:
     # output must be a writeable directory
     if not os.path.isdir(output):
         print(usage)
-        print(('If format set, output <%s> must be a writable directory' % (output)))
-    else:
-        if not os.access(output, os.W_OK):
-            print(usage)
-            print(('If format set, output <%s> must be a writable directory' % (output)))
+        print(('If format set, output <%s> must be a writable directory.  To write to a single ascii file, do not specify format.' % (output)))
+        sys.exit(-1)
+    if not os.access(output, os.W_OK):
+        print(usage)
+        print(('If format set, output <%s> must be a writable directory.  To write to a single ascii file, do not specify format.' % (output)))
+        sys.exit(-1)
 
 # set startDate
 if startDate is None:
@@ -894,6 +896,7 @@ for i in range(numFiles):
     if showFiles and (format is None):
         outputFile.write('%s\n' % (expFileList[i].name))
     outputFileArg = getOutputFileArg(expFileList[i].name, format, output)
+    time.sleep(0.5)
     try:
         data = server.isprint(expFileList[i].name,
                               parms,
@@ -925,6 +928,7 @@ for i in range(numFiles):
             numIter = 50 # number of pieces to break exp into
             for j in range(numIter):
                 newParms = getTimeParms(expTimeList, numIter, j)
+                time.sleep(0.5)
                 try:
                     data = server.isprint(expFileList[i].name,
                                   parms,
