@@ -2,7 +2,7 @@
 
 """
 
-# $Id: madrigalWeb.py 6277 2017-11-06 19:13:17Z brideout $
+# $Id: madrigalWeb.py 6583 2018-09-27 16:49:53Z brideout $
 
 
 import os, os.path, sys
@@ -101,7 +101,14 @@ class MadrigalData:
             
         self.cgiurl = urlBase + result[1:(-1*len(cgiName))]
 
-        self.siteDict = self.__getSiteDict()
+        try:
+            self.siteDict = self.__getSiteDict()
+        except:
+            self.cgiurl = url
+            if not self.cgiurl[-1] == '/':
+                self.cgiurl += '/'
+            self.siteDict = self.__getSiteDict()
+            
 
         self.siteId = self.__getSiteId()
         
@@ -312,7 +319,7 @@ class MadrigalData:
 
         
 
-        page = mainUrl.read().decode('utf8')
+        page = mainUrl.read().decode('utf8', errors='replace')
         page = page.split('\n')
 
         mainUrl.close()
@@ -655,6 +662,8 @@ class MadrigalData:
                 version = self.getVersion()
                 if distutils.version.LooseVersion(version) < distutils.version.LooseVersion('3.0'):
                     raise ValueError('Madrigal site at %s is below 3.0, cannot convert to Hdf5 or netCDF4' % (self.cgiurl))
+        else:
+            format = 'ascii'
 
         # read main url
         try:
@@ -662,18 +671,25 @@ class MadrigalData:
         except:
             raise ValueError('unable to open url ' + str(url))
                 
-        page = mainUrl.read().decode('utf-8')
+        if format == 'ascii':
+            page = mainUrl.read().decode('utf-8')
+        else:
+            page = mainUrl.read()
 
         mainUrl.close()
 
-        if page.find('Error occurred') != -1 and format == 'ascii':
-            raise ValueError('error raised using url ' + str(url))
+        if format == 'ascii':
+            if page.find('Error occurred') != -1:
+                raise ValueError('error raised using url ' + str(url))
     
         if outputFile is None:
             return page
         
         else:
-            f = open(outputFile, 'w')
+            if format == 'ascii':
+                f = open(outputFile, 'w')
+            else:
+                f = open(outputFile, 'wb')
             f.write(page)
             f.close()
 
@@ -1760,7 +1776,21 @@ class MadrigalData:
 
         while(True):
             if format in ('ascii', 'simple'):
-                data = urlFile.read(CHUNK).decode('utf8')
+                try:
+                    data = urlFile.read(CHUNK).decode('utf8')
+                except:
+                    # probably gzip ascii - convert
+                    f.close()
+                    try:
+                        os.remove(destination)
+                    except:
+                        pass
+                    urlFile.close()
+                    urlFile = urllib2.urlopen(url)
+                    f = open(destination + '.gz', 'wb')
+                    format = 'gzip'
+                    data = urlFile.read(CHUNK)
+                    
             else:
                 data = urlFile.read(CHUNK)
             if not data:
@@ -1830,11 +1860,11 @@ class MadrigalData:
         
         url = urlparse.urljoin(self.cgiurl,'downloadWebFileService.py')
         
-        url += '?expPath=%s' % (expPath)
+        url += '?expPath=%s' % (expPath.replace(' ', '+'))
         
         urlFile = urllib2.urlopen(url)
 
-        data = urlFile.read().decode('utf-8')
+        data = urlFile.read()
 
         urlFile.close()
         
